@echo off
REM BEGIN COPYRIGHT
REM *************************************************************************
REM Licensed Materials - Property of IBM 
REM 5724-L01, 5655-N53, 5724-I82, 5655-R15
REM (C) Copyright IBM Corporation 2006, 2009. All rights reserved. 
REM US Government Users Restricted Rights - Use, duplication, or disclosure
REM restricted by GSA ADP Schedule Contract with IBM Corp.
REM *************************************************************************
REM END COPYRIGHT
REM 
REM ------------------------------------------------------------------------------------------------------
REM -- Description:   Configure DB2 Database environment for CommonDB during Migrtaion based 
REM --			      Migrating Product profileType and its version
REM --                This file for use on Windows systems
REM --                This batch file updates CommonDB database 
REM --                This script shall not be used if profileType is esbserver and product version is 602
REM --				  
REM -- Usage: 
REM --                upgradeSchema.bat  <profileType> <product_version>  <dbName> <dbUserId>
REM -- Example:
REM --                upgradeSchema.bat wbiserver 620 WPRCSDB db2admin  
REM --                password will be prompted
REM ------------------------------------------------------------------------------------------------------
setlocal

SET CUR_DIR=%cd%

%~d0
cd %~p0

if  "%1" == "-h"  	goto PRINT_USAGE
if  "%1" == "-help"  	goto PRINT_USAGE

if "%1" == "esbserver" (
	if "%2" == "602" (
		goto PRINT_NO_SUPPORT
	)
)
set PROFILE_TYPE=%1
set PRODUCT_VERSION=%2
set DB_NAME=%3
set DB_USER=%4

if  not "%1" == ""  (
	if not "%2" == ""  (
  		if not "%3" == ""  (
  			if not "%4" == ""  (
				goto INPUT_PROFILE_TYPE
			} else (
	  			goto INPUT_USERNAME
			)
  		) else (
	  		goto INPUT_DBNAME
		)
  	) else (
 		goto INPUT_VERSION
  )
)

:INPUT_PROFILE_TYPE
if "%PROFILE_TYPE%"==""  (
  set /p PROFILE_TYPE="Enter profileType that you migrated [wbiserver | esbserver ]:": 
  goto INPUT_PROFILE_TYPE
)

:INPUT_VERSION
if "%PRODUCT_VERSION%"==""  (
  set /p PRODUCT_VERSION="Enter product version that you migrated [620 | 612 | 610 | 602]:":
  goto INPUT_VERSION
)

if "%PROFILE_TYPE%" == "esbserver" (
	if "%PRODUCT_VERSION%" == "602" (
		goto PRINT_NO_SUPPORT
	)
)

:INPUT_DBNAME
if "%DB_NAME%"==""  (
  set /p DB_NAME="Enter DB2 Database Name[WPRCSDB]:":  
  goto INPUT_DBNAME
)

:INPUT_USERNAME
if "%DB_USER%"==""  (
  set /p DB_USER="Enter DB2 user[dbUserId]:":
  goto INPUT_USERNAME
)

db2cmd /w /c /i .\upgradeSchemaTables.bat %PROFILE_TYPE% %PRODUCT_VERSION% %DB_NAME% %DB_USER% 

if not %ERRORLEVEL%==0 (
    goto PRINT_USAGE
) else (
    goto END 
)

:PRINT_NO_SUPPORT

echo.
echo  Common Database Schema upgrade from esbserver 602 is not supported. 
echo  Check Migration Topics in InfoCenter for more information....
		

goto END

:PRINT_USAGE

REM Print usage messages

echo.
echo =============================================================================================
echo Usage: upgradeSchema.bat ^<profileType^> ^<product_version^>  ^<dbName^> ^<dbUserId^>
echo Parameters:
echo profileType       -  Specify the migrated profileType  i.e., wbiserver or esbserver
echo product_version   -  Specify the migration version i.e., 620 or 612 or 610 or 602
echo dbName            -  DB2 Database Name(dbName) i.e., WPRCSDB 
echo dbUserId          -  User who can execute common scripts i.e.,dbUserId
echo Examples:
echo         1. upgradeSchema.bat -help
echo         2. upgradeSchema.bat [interactive mode]
echo         3. upgradeSchema.bat wbiserver 620 WPRCSDB db2admin 
echo         Note: This script shall not be used if profileType is esbserver and product version is 602
echo.              
echo =============================================================================================

goto END

:END
cd /d "%CUR_DIR%"
endlocal
