@echo off
REM
REM BEGIN COPYRIGHT
REM *************************************************************************
REM Licensed Materials - Property of IBM 
REM 5724-L01, 5655-N53, 5724-I82, 5655-R15
REM (C) Copyright IBM Corporation 2006, 2009. All rights reserved. 
REM US Government Users Restricted Rights - Use, duplication, or disclosure
REM restricted by GSA ADP Schedule Contract with IBM Corp.
REM *************************************************************************
REM END COPYRIGHT
REM
REM ----------------------------------------------------------------------------------------------------------------
REM 
REM
REM The SQL Server JDBC driver only supports mixed authentication mode. Therefore,
REM when the SQL Server instance is created, the authentication must be set to
REM "SQL Server and Windows"
REM Make sure OSQL command can be invoked from command line
REM
REM Description:   Configure SQLSERVER Database environment for CommonDB during Migrtaion based 
REM 			   Migrating WBI version
REM                This file for use on Windows systems
REM                This batch file updates CommonDB database 
REM                This script shall not be used if profileType is esbserver and product version is 602 
REM                Run the script always where it is located rather running from different folder
REM Usage: 
REM                upgradeSchema.bat  <profileType> <product_version>  <dbName> <dbUserId> <dbPassword> <dbHostName>
REM Example:1
REM                upgradeSchema.bat wbiserver 620 WPRCSDB dbUserId dbPassword host.ibm.com
REM ----------------------------------------------------------------------------------------------------------------
setlocal

SET CUR_DIR=%cd%

%~d0
cd %~p0


if  "%1" == "-h"  	goto PRINT_USAGE
if  "%1" == "-help"  	goto PRINT_USAGE

if "%1" == "esbserver" (
	if "%2" == "602" (
		goto PRINT_NO_SUPPORT
	)
)

set PROFILE_TYPE=%1
set PRODUCT_VERSION=%2
set DB_NAME=%3
set DB_USER=%4
set DB_PASSWORD=%5
set DB_HOST=%6

if  not "%1" == ""  (
	if not "%2" == ""  (
  		if not "%3" == ""  (
  			if not "%4" == ""  (
  				if not "%5" == ""  (
  					if not "%6" == ""  (
						goto INPUT_PROFILE_TYPE
					) else (
					 	goto INPUT_HOSTNAME
					)
				) else (
	  	  			goto INPUT_PASSWORD
				) 
			) else (
	  	  		goto INPUT_USERNAME
  			) 
  		) else (
	  		 goto INPUT_DBNAME
		) 
	) else (
		goto INPUT_PRODUCT_VERSION
	)
)

:INPUT_PROFILE_TYPE
if "%PROFILE_TYPE%"==""  (
  set /p PROFILE_TYPE="Enter profileType that you migrated [wbiserver | esbserver ]:": 
  goto INPUT_PROFILE_TYPE
)

:INPUT_PRODUCT_VERSION
if "%PRODUCT_VERSION%"==""  (
  set /p PRODUCT_VERSION="Enter product version that you migrated [620 | 612 | 610 | 602]:": 
  goto INPUT_PRODUCT_VERSION
)

if "%PROFILE_TYPE%" == "esbserver" (
	if "%PRODUCT_VERSION%" == "602" (
		goto PRINT_NO_SUPPORT
	)
)


:INPUT_DBNAME
if "%DB_NAME%"==""  (
  set /p DB_NAME="Enter SQL Server Database Name[WPRCSDB]:":  
  goto INPUT_DBNAME
)

:INPUT_USERNAME
if "%DB_USER%"==""  (
  set /p DB_USER="Enter SQL Server user[dbUserId]:":
  goto INPUT_USERNAME
)

:INPUT_PASSWORD
if "%DB_PASSWORD%"==""  (
  set /p DB_PASSWORD="Enter SQL Server password[dbPassword]:":
  goto INPUT_PASSWORD
)

:INPUT_HOSTNAME
if "%DB_HOST%"==""  (
  set /p DB_HOST="Enter SQL Server host[dbHostName]:":
  goto INPUT_HOSTNAME
)

REM :SERVER
set SERVER_PARAM=-S %DB_HOST%
if "%SERVER%"=="" set SERVER_PARAM=

set CONNECTION_ID=-U %DB_USER% -P %DB_PASSWORD%

REM --  CONNECT TO THE EXISTING DATABSE FOR COMMONDB UPDATES

dir /B | findstr "^upgradeSchema%PRODUCT_VERSION%_" > %PRODUCT_VERSION%.log

if  "%PROFILE_TYPE%" == "wbiserver"   dir /B | findstr "^wbiserver_upgradeSchema%PRODUCT_VERSION%_" >> %PRODUCT_VERSION%.log
if "%PROFILE_TYPE%" == "esbserver"    dir /B | findstr "^esbserver_upgradeSchema%PRODUCT_VERSION%_" >> %PRODUCT_VERSION%.log


for /F "tokens=1* delims=" %%v in ( %PRODUCT_VERSION%.log ) do (
    osql -b -d %DB_NAME% %SERVER_PARAM% %CONNECTION_ID% -i%%v
	if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto PRINT_USAGE
)

if not %ERRORLEVEL%==0 (
    goto PRINT_USAGE
) else (
    goto END 
)

:PRINT_NO_SUPPORT

echo.
echo  Common Database Schema upgrade from esbserver 602 is not supported. 
echo  Check Migration Topics in InfoCenter for more information....
		

goto END


:PRINT_USAGE

REM Print usage messages
echo.
echo ======================================================================
echo Usage: upgradeSchema.bat ^<profileType^> ^<product_version^>  ^<dbName^> ^<dbUserId^> ^<dbPassword^> ^<dbHostName^>
echo.
echo Parameters:
echo profileType       -  Specify the migrated profileType  i.e., wbiserver or esbserver
echo product_version   -  Specify the migration version ie., 620 or 610 or 612 
echo dbName            -  SQL Database Name(dbName) ie., WPRCSDB 
echo dbUserId          -  User who can execute common scripts using dbName
echo dbPassword        -  Password for dbuser
echo dbHostName        -  Sql server HostName
echo.
echo Examples:
echo         1. upgradeSchema.bat -help
echo         1. upgradeSchema.bat [interactive mode]
echo         2. upgradeSchema.bat wbiserver 620 WPRCSDB dbUserId dbPassword host.ibm.com
echo         Note: This script shall not be used if profileType is esbserver and product version is 602
echo.             
echo ===========================================================================

goto END

:END

rem del  %PRODUCT_VERSION%.log
cd /d "%CUR_DIR%"
endlocal
